@@ -80,41 +80,15 @@ define ([
             'start': dactionStart('empProfileUpdate')
         }),
         
-        // Password change pending
-        target.push('passChangePending', {
-            'name': 'passChangePending',
-            'type': 'daction',
-            'menuText': 'Confirm new password',
-            'aclProfile': 'passerby',
-            'start': dactionStart('passChangePending')
-        }),
-
-        // Save changed password
-        target.push('saveChangedPassword', {
-            'name': 'saveChangedPassword',
-            'type': 'daction',
-            'menuText': 'Save new password',
-            'aclProfile': 'passerby',
-            'start': dactionStart('saveChangedPassword')
-        }),
-    
         // New employee
-        target.push('newEmplSubmit', {
-            'name': 'newEmplSubmit',
+        target.push('ldapLookupSubmit', {
+            'name': 'ldapLookupSubmit',
             'type': 'daction',
-            'menuText': 'Save',
+            'menuText': 'Lookup',
             'aclProfile': 'admin',
-            'start': dactionStart('newEmplSubmit')
+            'start': dactionStart('ldapLookupSubmit')
         }),
         
-        // Insert employee
-        target.push('insertEmployee', {
-            'name': 'insertEmployee',
-            'type': 'daction',
-            'aclProfile': 'admin',
-            'start': dactionStart('insertEmployee')
-        }),
-    
         // Search employee
         target.push('actionEmplSearch', {
             'name': 'actionEmplSearch',
