@@ -72,10 +72,7 @@ define ([
             // actions triggered from employee menu
             "myProfile": empLib.myProfile,
             "empProfileUpdate": empLib.empProfileUpdate,
-            "passChangePending": empLib.passChangePending,
-            "saveChangedPassword": empLib.mainEmpl,
-            "newEmplSubmit": empLib.newEmplSubmit,
-            "insertEmployee": empLib.insertEmployee,
+            "ldapLookupSubmit": empLib.ldapLookupSubmit,
             "actionEmplSearch": empLib.actionEmplSearch,
             "masqEmployee": empLib.masqEmployee,
 
