@@ -117,22 +117,6 @@ define ([
             maxlen: 30
         },
 
-        // change password
-        'newPass': {
-            name: 'newPass',
-            aclProfileWrite: 'passerby',
-            text: 'Password',
-            prop: 'password',
-            maxlen: 32
-        },
-        'confirmPass': {
-            name: 'confirmPass',
-            aclProfileRead: 'passerby',
-            text: 'Password',
-            prop: 'password',
-            maxlen: 32
-        },
-        
         // new employee - nick
         'nEnick': {
             name: 'nEnick',
@@ -213,55 +197,42 @@ define ([
             'aclProfile': 'admin',
             'entriesRead': [entries.ePnick, entries.ePfullname],
             'entriesWrite': [entries.ePremark],
-            'hook': function () { return currentUser('obj'); },
+            'hook': empLib.getEmployeeObject,
             'miniMenu': {
                 entries: ['empProfileUpdate'],
                 back: ['Back', 'empProfile']
             }
         });
 
-        // target.push('changePassword', {
-        //     'name': 'changePassword',
-        //     'type': 'dform',
-        //     'menuText': 'Change my password',
-        //     'title': 'Change my password',
-        //     'preamble': 'Enter new password in the field below',
-        //     'aclProfile': 'passerby',
-        //     'entriesRead': [],
-        //     'entriesWrite': [entries.newPass],
-        //     'hook': function () { return currentUser('obj'); },
-        //     'miniMenu': {
-        //         entries: ['passChangePending'],
-        //         back: ['Back', 'mainEmpl']
-        //     }
-        // });
-
-        // target.push('confirmPassword', {
-        //     'name': 'confirmPassword',
-        //     'type': 'dform',
-        //     'title': 'NEW PASSWORD PENDING!',
-        //     'preamble': 'Check password and confirm that you really want it',
-        //     'aclProfile': 'passerby',
-        //     'entriesRead': [entries.confirmPass],
-        //     'hook': empLib.getEmployeeObject,
-        //     'miniMenu': {
-        //         entries: ['saveChangedPassword'],
-        //         back: ['Back', 'mainEmpl']
-        //     }
-        // });
-
-        target.push('newEmployee', {
-            'name': 'newEmployee',
+        target.push('ldapLookup', {
+            'name': 'ldapLookup',
             'type': 'dform',
-            'menuText': 'New employee',
-            'title': 'New employee',
-            'preamble': 'Fields marked (*) are required, others are optional.',
-            'aclProfile': 'admin',
+            'menuText': 'LDAP lookup',
+            'title': 'LDAP lookup',
+            'preamble': 'Enter employee nick for exact (case insensitive) match.',
+            'aclProfile': 'active',
             'entriesRead': null,
-            'entriesWrite': [entries.nEfullname, entries.nEnick, entries.nEemail, entries.nEremark],
+            'entriesWrite': [entries.nEnick],
             'hook': function () { return Object.create(prototypes.empProfile); },
             'miniMenu': {
-                entries: ['newEmplSubmit'],
+                entries: ['ldapLookupSubmit'],
+                back: ['Back', 'mainEmpl']
+            }
+        });
+
+        target.push('ldapLookupDisplay', {
+            'name': 'ldapLookupDisplay',
+            'type': 'dform',
+            'title': 'Employee profile',
+            'preamble': 'LDAP lookup success',
+            'aclProfile': 'active',
+            'entriesRead': [entries.ePfullname, entries.ePnick,
+                entries.ePsec_id, entries.ePemail, entries.ePremark,
+                entries.ePstatus, entries.ePstatusSince],
+            'entriesWrite': [],
+            'hook': empLib.getEmployeeObject,
+            'miniMenu': {
+                entries: ['masqEmployee'],
                 back: ['Back', 'mainEmpl']
             }
         });
