@@ -62,7 +62,8 @@ define ([
         getEmployeeObject = function () { return employeeObject; },
 
         myProfile = function () {
-            if (employeeObject.effective !== null) {
+            var cu = currentUser('obj');
+            if (employeeObject.effective !== null && employeeObject.nick === cu.nick) {
                 target.pull('empProfile').start();
             } else {
                 loadEmpProfile(currentUser('obj').eid);
@@ -78,8 +79,13 @@ define ([
                 sc = function (st) {
                     if (st.code === 'DISPATCH_EMPLOYEE_PROFILE_FULL') {
                         console.log("Payload is", st.payload);
-                        var effective = st.payload.privhistory.effective;
-                        effective = effective.substr(0, effective.indexOf(" "));
+                        var priv = null,
+                            effective = null;
+                        if (st.payload.privhistory !== null) {
+                            priv = st.payload.privhistory.priv
+                            effective = st.payload.privhistory.effective
+                            effective = effective.substr(0, effective.indexOf(" "));
+                        }
                         employeeObject = $.extend(
                             Object.create(prototypes.empProfile), {
                                 'eid': st.payload.emp.eid,
@@ -88,7 +94,7 @@ define ([
                                 'email': st.payload.emp.email,
                                 'remark': st.payload.emp.remark,
                                 'sec_id': st.payload.emp.sec_id,
-                                'priv': st.payload.privhistory.priv,
+                                'priv': priv,
                                 'effective': effective
                             }
                         );
@@ -131,26 +137,6 @@ define ([
             ajax(rest, sc, fc);
         },
 
-        // "insert employee" method
-        insertEmp = function (emp) {
-            var rest = {
-                    "method": 'PUT',
-                    "path": 'employee/nick/' + emp.nick,
-                    "body": emp.sanitize()
-                },
-                // success callback
-                sc = function (st) {
-                    console.log("Created new employee: ", st.payload);
-                    $('#result').html("Created new employee " + st.payload.nick);
-                    employeeObject = st.payload;
-                    setEmployeeObject(employeeObject);
-                    target.pull('empProfile').start();
-                },
-                // failure callback
-                fc = null;
-            ajax(rest, sc, fc);        
-        },
-
         // masquerade as a different employee
         currentEmployeeStashed = null,
         currentEmplPrivStashed = null,
@@ -189,7 +175,7 @@ define ([
                 currentUser('flag1', 1); // turn on masquerade flag
                 $('#userbox').html(appLib.fillUserBox()); // reset userbox
                 $('#mainarea').css("background-color", "red");
-                target.pull('mainMenu').start();
+                target.pull('mainEmpl').start();
                 return;
             }
         
@@ -197,40 +183,42 @@ define ([
             target.pull('searchEmployee').start();
         },
 
-        // "new employee" method - checks database if employee doesn't already exist
-        // and then calls insertEmp
-        newEmplSubmit = function (emp) {
-            console.log("Entering function newEmplSubmit");
+        ldapLookupSubmit = function (emp) {
+            console.log("Entering function ldapLookupSubmit");
             var rest = {
-                    method: 'GET',
-                    path: 'employee/nick/' + emp.nick || ''
+                    method: 'PUT',
+                    // path: 'employee/nick/' + emp.nick || ''
                 },
                 // success callback -- employee already exists
                 sc = function (st) {
-                    var message = 'Employee ' + emp.nick + ' already exists'
-                    console.log(message);
-                    $('#result').html(message);
-                    $('input[name="sel"]').focus();
-                    $('input[name="sel"]').val('');
+                    if (st.code === 'DOCHAZKA_CUD_OK') {
+                        console.log("Payload is", st.payload);
+                        employeeObject = $.extend(employeeObject, st.payload);
+                        target.pull('ldapLookupDisplay').start();
+                    }
                 },
                 // failure callback -- employee doesn't exist
                 fc = function (st) {
                     var err = st.payload.code;
                     if (err === '404') {
-                        console.log('Employee ' + emp.nick + ' not found');
-                        insertEmp(emp);
+                        var msg = 'Employee ' + emp.nick + ' not found in LDAP';
+                        console.log(msg);
+                        $("#result").html(msg);
+                        $('input[name="sel"]').val('');
+                        $('input[name="entry0"]').focus();
                     }
                 }
-            ajax(rest, sc, fc);        
+            if (emp.hasOwnProperty('nick')) {
+                rest.path = 'employee/nick/' + emp.nick + '/ldap';
+                ajax(rest, sc, fc);
+            }
         },
 
 	// epuGen ("generate employee profile update function") is called to
-	// save changes to the database, both for the 'empProfileEdit' form and
-	// the 'changePassword' form
+	// save changes to the database
         //
 	// the argument afterTarget is the name of the target to go to
-	// when the database update is finished -- this is the only parameter
-	// that differs between the two targets
+	// when the database update is finished
         //
         epuGen = function (afterTarget, emp) {
             var protoEmp = Object.create(prototypes.empProfile);
@@ -243,10 +231,7 @@ define ([
                 },
                 sc = function (st) {
                     // st is 'Status'
-                    if (afterTarget === 'mainEmpl') {
-                        // this is a change password operation
-                        $("#result").html("Password changed");
-                    } else if (afterTarget === 'empProfile') {
+                    if (afterTarget === 'empProfile') {
                         // this is an employee profile update
                         $("#result").html("Employee profile updated");
                     }
@@ -270,12 +255,7 @@ define ([
         myProfile: myProfile,
         loadEmpProfile: loadEmpProfile,
         empProfileUpdate: function (emp) { epuGen('empProfile', emp); },
-        passChangePending: function (emp) {
-            employeeObject = emp;
-            target.pull('confirmPassword').start();
-        },
-        newEmplSubmit: newEmplSubmit,
-        insertEmployee: insertEmp,
+        ldapLookupSubmit: ldapLookupSubmit,
         actionEmplSearch: searchEmp,
         endTheMasquerade: endTheMasquerade,
         masqEmployee: masqEmp
